@@ -25,6 +25,7 @@
 #include "status.h"
 #include "support.h"
 #include "K3_ui.h"
+#include "KX3_ui.h"
 #include "socket_io.h"
 #include "hspinner.h"
 #include "ui.h"
@@ -74,6 +75,7 @@ Fl_Light_Button *btnAutoNotch=(Fl_Light_Button *)0;
 Fl_Group *grp_row1b2=(Fl_Group *)0;
 Fl_Button *btnAswapB=(Fl_Button *)0;
 Fl_Button *btn_K3_swapAB=(Fl_Button *)0;
+Fl_Button *btn_KX3_swapAB=(Fl_Button *)0;
 Fl_Light_Button *btnB=(Fl_Light_Button *)0;
 Fl_Light_Button *btnSplit=(Fl_Light_Button *)0;
 Fl_Light_Button *btnPTT=(Fl_Light_Button *)0;
@@ -171,8 +173,10 @@ Fl_Group *genericMisc=(Fl_Group *)0;
 Hspinner *spnr_vfo_adj=(Hspinner *)0;
 Hspinner *spnr_line_out=(Hspinner *)0;
 Fl_Light_Button *btnSpecial=(Fl_Light_Button *)0;
+Fl_Check_Button *btn_ext_tuner=(Fl_Check_Button *)0;
 Fl_Check_Button *btn_xcvr_auto_on=(Fl_Check_Button *)0;
 Fl_Check_Button *btn_xcvr_auto_off=(Fl_Check_Button *)0;
+
 Fl_Group *genericRXB=(Fl_Group *)0;
 Hspinner *cntRIT=(Hspinner *)0;
 Hspinner *cntXIT=(Hspinner *)0;
@@ -364,6 +368,9 @@ static void cb_btn_K3_swapAB(Fl_Button*, void*) {
 	cb_K3_swapAB();
 }
 
+static void cb_btn_KX3_swapAB(Fl_Button*, void*) {
+	cb_KX3_swapAB();
+}
 
 static void cb_btnB(Fl_Light_Button*, void*) {
 	if (Fl::event_button() == FL_RIGHT_MOUSE) {
@@ -554,27 +561,27 @@ static void cb_btnSpot(Fl_Light_Button* o, void*) {
 	cb_cw_spot();
 }
 
-static void cb_spnr_cw_spot_tone(Fl_Counter* o, void*) {
+static void cb_spnr_cw_spot_tone(Hspinner* o, void*) {
 	progStatus.cw_spot_tone=(int)o->value();
 	cb_cw_spot_tone();
 }
 
-static void cb_spnr_cw_qsk(Fl_Counter* o, void*) {
+static void cb_spnr_cw_qsk(Hspinner* o, void*) {
 	progStatus.cw_qsk = o->value();
 	cb_cw_qsk();
 }
 
-static void cb_spnr_cw_weight(Fl_Counter* o, void*) {
+static void cb_spnr_cw_weight(Hspinner* o, void*) {
 	progStatus.cw_weight = o->value();
 	cb_cw_weight();
 }
 
-static void cb_spnr_cw_wpm(Fl_Counter* o, void*) {
+static void cb_spnr_cw_wpm(Hspinner* o, void*) {
 	progStatus.cw_wpm = o->value();
 	cb_cw_wpm();
 }
 
-static void cb_spnr_cw_delay(Fl_Counter* o, void*) {
+static void cb_spnr_cw_delay(Hspinner* o, void*) {
 	progStatus.cw_delay = o->value();
 	cb_cw_delay();
 }
@@ -589,17 +596,17 @@ static void cb_btnBreakIn(Fl_Check_Button* o, void*) {
 	cb_enable_break_in();
 }
 
-static void cb_spnr_vox_gain(Fl_Counter* o, void*) {
+static void cb_spnr_vox_gain(Hspinner* o, void*) {
 	progStatus.vox_gain=(int)o->value();
 	cb_vox_gain();
 }
 
-static void cb_spnr_anti_vox(Fl_Counter* o, void*) {
+static void cb_spnr_anti_vox(Hspinner* o, void*) {
 	progStatus.vox_anti=(int)o->value();
 	cb_vox_anti();
 }
 
-static void cb_spnr_vox_hang(Fl_Counter* o, void*) {
+static void cb_spnr_vox_hang(Hspinner* o, void*) {
 	progStatus.vox_hang = (int)o->value();
 	cb_vox_hang();
 }
@@ -619,7 +626,7 @@ static void cb_btnCompON(Fl_Light_Button* o, void*) {
 	cb_compression();
 }
 
-static void cb_spnr_compression(Fl_Counter* o, void*) {
+static void cb_spnr_compression(Hspinner* o, void*) {
 	progStatus.compression=(int)o->value();
 	cb_compression();
 }
@@ -634,7 +641,7 @@ static void cb_cbo_agc_level(Fl_ComboBox* o, void*) {
 	cb_agc_level();
 }
 
-static void cb_spnr_bpf_center(Fl_Counter* o, void*) {
+static void cb_spnr_bpf_center(Hspinner* o, void*) {
 	progStatus.bpf_center=o->value();
 	cb_bpf_center();
 }
@@ -644,12 +651,12 @@ static void cb_btn_use_bpf_center(Fl_Check_Button* o, void*) {
 	cb_bpf_center();
 }
 
-static void cb_spnr_vfo_adj(Fl_Counter* o, void*) {
+static void cb_spnr_vfo_adj(Hspinner* o, void*) {
 	progStatus.vfo_adj=o->value();
 	cb_vfo_adj();
 }
 
-static void cb_spnr_line_out(Fl_Counter* o, void*) {
+static void cb_spnr_line_out(Hspinner* o, void*) {
 	progStatus.line_out = o->value();
 	cb_line_out();
 }
@@ -658,6 +665,10 @@ static void cb_btnSpecial(Fl_Light_Button*, void*) {
 	cb_special();
 }
 
+static void cb_btn_ext_tuner(Fl_Check_Button* o, void*) {
+	progStatus.external_tuner = o->value();
+}
+
 static void cb_btn_xcvr_auto_on(Fl_Check_Button* o, void*) {
 	progStatus.xcvr_auto_on = o->value();
 }
@@ -666,15 +677,15 @@ static void cb_btn_xcvr_auto_off(Fl_Check_Button* o, void*) {
 	progStatus.xcvr_auto_off = o->value();
 }
 
-static void cb_cntRIT(Fl_Counter*, void*) {
+static void cb_cntRIT(Hspinner*, void*) {
 	cbRIT();
 }
 
-static void cb_cntXIT(Fl_Counter*, void*) {
+static void cb_cntXIT(Hspinner*, void*) {
 	cbXIT();
 }
 
-static void cb_cntBFO(Fl_Counter*, void*) {
+static void cb_cntBFO(Hspinner*, void*) {
 	cbBFO();
 }
 
@@ -695,27 +706,27 @@ static void cb_btnDataPort(Fl_Light_Button* o, void*) {
 	btnDataPort->redraw_label();
 }
 
-static void cb_spnr_tt550_cw_wpm(Fl_Counter* o, void*) {
+static void cb_spnr_tt550_cw_wpm(Hspinner* o, void*) {
 	progStatus.tt550_cw_wpm = (int)o->value();
 	cb_tt550_cw_wpm();
 }
 
-static void cb_spnr_tt550_cw_weight(Fl_Counter* o, void*) {
+static void cb_spnr_tt550_cw_weight(Hspinner* o, void*) {
 	progStatus.tt550_cw_weight = o->value();
 	cb_tt550_cw_weight();
 }
 
-static void cb_spnr_tt550_cw_qsk(Fl_Counter* o, void*) {
+static void cb_spnr_tt550_cw_qsk(Hspinner* o, void*) {
 	progStatus.tt550_cw_qsk = (int)o->value();
 	cb_tt550_cw_qsk();
 }
 
-static void cb_spnr_tt550_cw_vol(Fl_Counter* o, void*) {
+static void cb_spnr_tt550_cw_vol(Hspinner* o, void*) {
 	progStatus.tt550_cw_vol=(int)o->value();
 	cb_tt550_cw_vol();
 }
 
-static void cb_spnr_tt550_cw_spot(Fl_Counter* o, void*) {
+static void cb_spnr_tt550_cw_spot(Hspinner* o, void*) {
 	progStatus.tt550_cw_spot=(int)o->value();
 	cb_tt550_cw_spot();
 }
@@ -725,17 +736,17 @@ static void cb_btn_tt550_enable_keyer(Fl_Check_Button* o, void*) {
 	cb_tt550_enable_keyer();
 }
 
-static void cb_spnr_tt550_vox_gain(Fl_Counter* o, void*) {
+static void cb_spnr_tt550_vox_gain(Hspinner* o, void*) {
 	progStatus.tt550_vox_gain=(int)o->value();
 	cb_tt550_vox_gain();
 }
 
-static void cb_spnr_tt550_anti_vox(Fl_Counter* o, void*) {
+static void cb_spnr_tt550_anti_vox(Hspinner* o, void*) {
 	progStatus.tt550_vox_anti=(int)o->value();
 	cb_tt550_vox_anti();
 }
 
-static void cb_spnr_tt550_vox_hang(Fl_Counter* o, void*) {
+static void cb_spnr_tt550_vox_hang(Hspinner* o, void*) {
 	progStatus.tt550_vox_hang = (int)o->value();
 	cb_tt550_vox_hang();
 }
@@ -750,17 +761,17 @@ static void cb_btn_tt550_CompON(Fl_Light_Button* o, void*) {
 	cb_tt550_compression();
 }
 
-static void cb_spnr_tt550_compression(Fl_Counter* o, void*) {
+static void cb_spnr_tt550_compression(Hspinner* o, void*) {
 	progStatus.tt550_compression=(int)o->value();
 	cb_tt550_compression();
 }
 
-static void cb_spnr_tt550_mon_vol(Fl_Counter* o, void*) {
+static void cb_spnr_tt550_mon_vol(Hspinner* o, void*) {
 	progStatus.tt550_mon_vol=(int)o->value();
 	cb_tt550_mon_vol();
 }
 
-static void cb_spnr_tt550_line_out(Fl_Counter* o, void*) {
+static void cb_spnr_tt550_line_out(Hspinner* o, void*) {
 	progStatus.tt550_line_out = (int)o->value();
 	cb_tt550_line_out();
 }
@@ -780,7 +791,7 @@ static void cb_cbo_tt550_agc_level(Fl_ComboBox* o, void*) {
 	cb_tt550_agc_level();
 }
 
-static void cb_spnr_tt550_vfo_adj(Fl_Counter* o, void*) {
+static void cb_spnr_tt550_vfo_adj(Hspinner* o, void*) {
 	progStatus.vfo_adj=o->value();
 	cb_vfo_adj();
 }
@@ -810,11 +821,11 @@ static void cb_btn_tt550_use_xmt_bw(Fl_Check_Button* o, void*) {
 	cb_tt550_setXmtBW();
 }
 
-static void cb_spnr_tt550_keypad_time_out(Fl_Counter* o, void*) {
+static void cb_spnr_tt550_keypad_time_out(Hspinner* o, void*) {
 	progStatus.tt550_keypad_timeout=(int)(o->value()*1000.0);
 }
 
-static void cb_spnr_tt550_encoder_sensitivity(Fl_Counter* o, void*) {
+static void cb_spnr_tt550_encoder_sensitivity(Hspinner* o, void*) {
 	progStatus.tt550_encoder_sensitivity = o->value();
 }
 
