@@ -24,7 +24,7 @@ void cbBUTTONS(Fl_Widget *, void *);
 void cbOTHER(Fl_Widget *, void *);
 
 Fl_Menu_Item touch_menu[] = {
- {_("&Files"), 0,  0, 0, 64, FL_NORMAL_LABEL, 0, 14, 0},
+ {_("&File"), 0,  0, 0, 64, FL_NORMAL_LABEL, 0, 14, 0},
  {_("E&xit"), 0,  (Fl_Callback*)cb_mnuExit, 0, 0, FL_NORMAL_LABEL, 0, 14, 0},
  {0,0,0,0,0,0,0,0,0},
  {_("&Config"), 0,  0, 0, 64, FL_NORMAL_LABEL, 0, 14, 0},
@@ -644,6 +644,13 @@ Fl_Group *touch_main_group(int X, int Y, int W, int H)
 		btn_K3_swapAB->callback((Fl_Callback*)cb_btn_K3_swapAB);
 		btn_K3_swapAB->hide();
 
+		btn_KX3_swapAB = new Fl_Button(xpos, ypos, bw, bh, _("A/B"));
+		btn_KX3_swapAB->tooltip(_("Swap A/B"));
+		btn_KX3_swapAB->down_box(FL_DOWN_BOX);
+		btn_KX3_swapAB->labelsize(16);
+		btn_KX3_swapAB->callback((Fl_Callback*)cb_btn_KX3_swapAB);
+		btn_KX3_swapAB->hide();
+
 		xpos += btn_K3_swapAB->w() + 2;
 		btnSplit = new Fl_Light_Button(xpos, ypos, bw, bh, _("Split"));
 		btnSplit->tooltip(_("Rx-A / Tx-B"));
@@ -995,10 +1002,21 @@ Fl_Group *touch_main_group(int X, int Y, int W, int H)
 					by, 74, bh, _("Special"));
 				btnSpecial->callback((Fl_Callback*)cb_btnSpecial);
 
-				btn_xcvr_auto_on = new Fl_Check_Button(
+				btn_ext_tuner = new Fl_Check_Button(
 					btnSpecial->x() +
 					btnSpecial->w() + 8,
-					by, 95, bh, _("Rig autOn"));
+					by, 95, bh, 
+					_("Ext tuner"));
+				btn_ext_tuner->tooltip(_("use external auto tuner"));
+				btn_ext_tuner->down_box(FL_DOWN_BOX);
+				btn_ext_tuner->callback((Fl_Callback*)cb_btn_ext_tuner);
+				btn_ext_tuner->value(progStatus.external_tuner);
+
+				btn_xcvr_auto_on = new Fl_Check_Button(
+					btn_ext_tuner->x() +
+					btn_ext_tuner->w() + 8,
+					by, 95, bh, 
+					_("Rig autOn"));
 				btn_xcvr_auto_on->tooltip(_("Auto Turn Rig On with Flrig startup"));
 				btn_xcvr_auto_on->down_box(FL_DOWN_BOX);
 				btn_xcvr_auto_on->callback((Fl_Callback*)cb_btn_xcvr_auto_on);
@@ -1274,7 +1292,7 @@ Fl_Group *touch_main_group(int X, int Y, int W, int H)
 				tt550_Rx->hide();
 
 				cbo_tt550_nb_level = new Fl_ComboBox(xpos+80, by, 89, bh, _("NB level"));
-				cbo_tt550_nb_level->tooltip(_("Select Transceiver"));
+				cbo_tt550_nb_level->tooltip(_("Select Noise Blanker level"));
 				cbo_tt550_nb_level->box(FL_DOWN_BOX);
 				cbo_tt550_nb_level->color(FL_BACKGROUND_COLOR);
 				cbo_tt550_nb_level->selection_color(FL_BACKGROUND_COLOR);
@@ -1292,7 +1310,7 @@ Fl_Group *touch_main_group(int X, int Y, int W, int H)
 					cbo_tt550_nb_level->x() +
 					cbo_tt550_nb_level->w() + 60, by,
 					90, bh, _("AGC"));
-				cbo_tt550_agc_level->tooltip(_("Select Transceiver"));
+				cbo_tt550_agc_level->tooltip(_("Select AGC"));
 				cbo_tt550_agc_level->box(FL_DOWN_BOX);
 				cbo_tt550_agc_level->color(FL_BACKGROUND_COLOR);
 				cbo_tt550_agc_level->selection_color(FL_BACKGROUND_COLOR);
@@ -1311,9 +1329,12 @@ Fl_Group *touch_main_group(int X, int Y, int W, int H)
 					cbo_tt550_agc_level->w() + 120, by,
 					5*bh, bh, _("Vfo Adj(ppm)"));
 				spnr_tt550_vfo_adj->callback((Fl_Callback*)cb_spnr_tt550_vfo_adj);
-				spnr_tt550_vfo_adj->align(Fl_Align(36));
+				spnr_tt550_vfo_adj->align(FL_ALIGN_BOTTOM | FL_ALIGN_CENTER);
+				spnr_tt550_vfo_adj->minimum(-100);
+				spnr_tt550_vfo_adj->maximum(100);
+				spnr_tt550_vfo_adj->type(FL_FLOAT_INPUT);
+				spnr_tt550_vfo_adj->step(0.1);
 				spnr_tt550_vfo_adj->value(progStatus.vfo_adj);
-				spnr_tt550_vfo_adj->step(1.0);
 
 			tt550_Rx->end();
 
@@ -1339,7 +1360,7 @@ Fl_Group *touch_main_group(int X, int Y, int W, int H)
 				op_tt550_XmtBW = new Fl_ComboBox(xpos+462, by, 112, bh, _("Xmt BW"));
 				op_tt550_XmtBW->tooltip(_("Select Transceiver Bandwidth"));
 				op_tt550_XmtBW->box(FL_DOWN_BOX);
-				op_tt550_XmtBW->color(FL_BACKGROUND_COLOR);
+				op_tt550_XmtBW->color(FL_WHITE);
 				op_tt550_XmtBW->selection_color(FL_BACKGROUND_COLOR);
 				op_tt550_XmtBW->labeltype(FL_NORMAL_LABEL);
 				op_tt550_XmtBW->labelfont(0);
