@@ -47,7 +47,7 @@ struct GUI {
 };
 
 enum {onA, onB};
-enum {UI, XML};
+enum {UI, XML, SRVR};
 
 enum {BINARY, STRING};
 
@@ -64,7 +64,7 @@ enum {
 	IC7000, IC7100, IC7200, IC7410, IC7600, IC7700,
 	IC9100, IC910H,
 
-	K2, K3,
+	K2, K3, KX3,
 
 	PCR1000,
 
@@ -199,6 +199,7 @@ public:
 	bool use_line_in;
 	bool has_bpf_center;
 	bool has_special;
+	bool has_ext_tuner;
 	bool has_band_selection;
 
 	bool restore_mbw;
