@@ -86,6 +86,7 @@ extern Fl_Group *grp_row0a;
 
 extern Fl_Light_Button *btnA;
 extern Fl_Button *btn_K3_swapAB;
+extern Fl_Button *btn_KX3_swapAB;
 extern Fl_Light_Button *btnB;
 extern Fl_Button *btnTune;
 extern Fl_Box *bx_row0_expander;
@@ -189,6 +190,7 @@ extern Fl_Group *genericMisc;
 extern Hspinner *spnr_vfo_adj;
 extern Hspinner *spnr_line_out;
 extern Fl_Light_Button *btnSpecial;
+extern Fl_Check_Button *btn_ext_tuner;
 extern Fl_Check_Button *btn_xcvr_auto_on;
 extern Fl_Check_Button *btn_xcvr_auto_off;
 extern Fl_Group *genericRXB;
