@@ -70,7 +70,8 @@
 #include "debug.h"
 #include "util.h"
 #include "gettext.h"
-#include "xml_io.h"
+#include "xml_server.h"
+
 #include "ui.h"
 
 #include "flrig_icon.cxx"
@@ -86,7 +87,6 @@ string defFileName;
 string title;
 
 pthread_t *serial_thread = 0;
-pthread_t *digi_thread = 0;
 
 pthread_mutex_t mutex_serial = PTHREAD_MUTEX_INITIALIZER;
 pthread_mutex_t mutex_xmlrpc = PTHREAD_MUTEX_INITIALIZER;
@@ -392,13 +392,7 @@ int main (int argc, char *argv[])
 		exit(EXIT_FAILURE);
 	}
 
-	open_rig_xmlrpc();
-
-	digi_thread = new pthread_t;      
-	if (pthread_create(digi_thread, NULL, digi_loop, NULL)) {
-		perror("pthread_create");
-		exit(EXIT_FAILURE);
-	}
+	start_server();
 
 	createXcvrDialog();
 
