@@ -17,18 +17,16 @@
 // You should have received a copy of the GNU General Public License
 // along with this program.  If not, see <http://www.gnu.org/licenses/>.
 // ----------------------------------------------------------------------------
-/*
- * Changes for the TS-870S March 2012, Dave Baxter, G0WBX
-/
-
- /* Todo:
- * Look at:-												(Example)
- * Autonotch control:- 	(SSB Only on the 870S)				(TS-2000)
- * Noise Reduction control:- 								(IC-7700)
- * Extra controls for speach compressor etc:- 				(IC-9100 (and others))
- * Misc controls auto rig on/off with flrig startup/quit:-	(FT-450/950) (PS0; PS1;)
- * Check Autotune action, and any 'busy' status.
- */
+//
+// Changes for the TS-870S March 2012, Dave Baxter, G0WBX
+//
+// Todo:
+// Look at:-												(Example)
+// Autonotch control:- 	(SSB Only on the 870S)				(TS-2000)
+// Noise Reduction control:- 								(IC-7700)
+// Extra controls for speach compressor etc:- 				(IC-9100 (and others))
+// Misc controls auto rig on/off with flrig startup/quit:-	(FT-450/950) (PS0; PS1;)
+// Check Autotune action, and any 'busy' status.
 
 #include "config.h"
 #include "TS870S.h"
@@ -45,6 +43,7 @@ static const char TS870S_mode_type[] = { 'L',   'U',   'U',  'U',  'U',  'L',
 static const char *TS870S_empty[] = { "N/A", NULL };
 
 //----------------------------------------------------------------------
+static int DEF_lo_hi = 0x8704;
 static const char *TS870S_SSB_lo[] = { 			// MD1; and MD2;
   "0",   "50", "100", "200", "300", 			// Available settings (Hz)
 "400",  "500", "600", "800", "1000", NULL };
@@ -53,7 +52,7 @@ static const char *TS870S_CAT_ssb_lo[] = {		// Corresponding commands.
 "FW0000;", "FW0005;", "FW0010;", "FW0020;", "FW0030;",
 "FW0040;", "FW0050;", "FW0060;", "FW0080;", "FW0100;", NULL };
 
-static const char *TS870S_SSB_lo_tooltip = "lo cutoff";
+static const char *TS870S_SSB_lo_tooltip = "lo cut";
 static const char *TS870S_SSB_btn_lo_label = "L";
 
 
@@ -65,7 +64,7 @@ static const char *TS870S_CAT_ssb_hi[] = {		// Corresponding commands.
 "IS 1400;", "IS 1600;", "IS 1800;", "IS 2000;", "IS 2200;", "IS 2400;",
 "IS 2600;", "IS 2800;", "IS 3000;", "IS 3400;", "IS 4600;", "IS 6000;", NULL };
 
-static const char *TS870S_SSB_hi_tooltip = "hi cutoff";
+static const char *TS870S_SSB_hi_tooltip = "hi cut";
 static const char *TS870S_SSB_btn_hi_label = "H";
 
 //----------------------------------------------------------------------
@@ -75,7 +74,7 @@ static const char *TS870S_AM_lo[] = { // Available values...
 static const char *TS870S_CAT_am_lo[] = { // ... Corresponding commands.
 "FW0000;", "FW0010;", "FW0020;", "FW0050;", NULL};
 
-static const char *TS870S_AM_lo_tooltip = "lo cutoff";
+static const char *TS870S_AM_lo_tooltip = "lo cut";
 static const char *TS870S_AM_btn_lo_label = "L";
 
 static const char *TS870S_AM_hi[] = {
@@ -84,7 +83,7 @@ static const char *TS870S_AM_hi[] = {
 static const char *TS870S_CAT_am_hi[] = {
 "IS 2500;", "IS 3000;", "IS 4000;", "IS 5000;", "IS 6000;", "IS 7000;", NULL};
 
-static const char *TS870S_AM_hi_tooltip = "hi cutoff";
+static const char *TS870S_AM_hi_tooltip = "hi cut";
 static const char *TS870S_AM_btn_hi_label = "H";
 
 //----------------------------------------------------------------------
@@ -149,7 +148,7 @@ RIG_TS870S::RIG_TS870S() {
 
 	name_ = TS870Sname_;
 	modes_ = TS870Smodes_;
-	bandwidths_ = TS870S_empty;
+	bandwidths_ = TS870S_SSB_hi;
 
 	dsp_lo     = TS870S_SSB_lo;
 	lo_tooltip = TS870S_SSB_lo_tooltip;
@@ -174,8 +173,8 @@ RIG_TS870S::RIG_TS870S() {
 	comm_dtrptt = false;    // ditto
 
 //	Defaults.
-	B.imode = A.imode = 1;      // USB
-	B.iBW = A.iBW = 0x8704;     // hi=2800Hz .. lo=300Hz
+	B.imode = A.imode = USB;
+	B.iBW = A.iBW = DEF_lo_hi;
 	B.freq = A.freq = 14070000;
 	can_change_alt_vfo = true;
 
@@ -248,7 +247,7 @@ void RIG_TS870S::selectA()
 {
 	cmd = "FR0;";
 	sendCommand(cmd);
-	showresp(WARN, ASC, "Rx/Tx A", cmd, replystr);
+	showresp(WARN, ASC, "Rx/Tx A", cmd, "");
 	vfo = 0;
 }
 
@@ -257,7 +256,7 @@ void RIG_TS870S::selectB()
 {
 	cmd = "FR1;";
 	sendCommand(cmd);
-	showresp(WARN, ASC, "Rx/Tx B", cmd, replystr);
+	showresp(WARN, ASC, "Rx/Tx B", cmd, "");
 	vfo = 1;
 }
 
@@ -269,10 +268,8 @@ void RIG_TS870S::set_split(bool val)
 // find out which VFO (or if Memory) is in use for RX.
 
 	cmd = "FR;";   sendCommand(cmd);
-	showresp(WARN, ASC, "RX-VFO?", cmd, replystr);
-	int ret = waitN(4, 100, "get VFO for split", ASC);
-// if incomplete data, change nothing.
-	if (ret < 4) return;
+	showresp(WARN, ASC, "RX-VFO?", cmd, "");
+	if (wait_char(';', 4, 100, "get VFO for split", ASC) < 4) return;
 
 	size_t p = replystr.rfind("FR");
 // if bad data, change nothing.
@@ -291,21 +288,21 @@ void RIG_TS870S::set_split(bool val)
 		if (val) {
 			cmd = "FR1;FT0;";
 			sendCommand(cmd);
-			showresp(WARN, ASC, "Rx on B, Tx on A", cmd, replystr);
+			showresp(WARN, ASC, "Rx on B, Tx on A", cmd, "");
 		} else {
 			cmd = "FR1;FT1;";
 			sendCommand(cmd);
-			showresp(WARN, ASC, "Rx on B, Tx on B", cmd, replystr);
+			showresp(WARN, ASC, "Rx on B, Tx on B", cmd, "");
 		}
 	} else {
 		if (val) {
 			cmd = "FR0;FT1;";
 			sendCommand(cmd);
-			showresp(WARN, ASC, "Rx on A, Tx on B", cmd, replystr);
+			showresp(WARN, ASC, "Rx on A, Tx on B", cmd, "");
 		} else {
 			cmd = "FR0;FT0;";
 			sendCommand(cmd);
-			showresp(WARN, ASC, "Rx on A, Tx on A", cmd, replystr);
+			showresp(WARN, ASC, "Rx on A, Tx on A", cmd, "");
 		}
 	}
 	Fl::awake(highlight_vfo, (void *)0);
@@ -319,26 +316,25 @@ int RIG_TS870S::get_split()
 {
 	size_t p;
 	int split = 0;
-	char rx, tx;
+	char rx = 0, tx = 0;
 // tx vfo
 	cmd = rsp = "FT";
 	cmd.append(";");
-	waitN(4, 100, "get split tx vfo", ASC);
-	p = replystr.rfind(rsp);
-	if (p == string::npos) return split;
-	tx = replystr[p+2];
-
+	if (wait_char(';', 4, 100, "get split tx vfo", ASC) == 4) {
+		p = replystr.rfind(rsp);
+		if (p == string::npos) return split;
+		tx = replystr[p+2];
+	}
 // rx vfo
 	cmd = rsp = "FR";
 	cmd.append(";");
-	waitN(4, 100, "get split rx vfo", ASC);
-
-	p = replystr.rfind(rsp);
-	if (p == string::npos) return split;
-	rx = replystr[p+2];
+	if (wait_char(';', 4, 100, "get split rx vfo", ASC) == 4) {
+		p = replystr.rfind(rsp);
+		if (p == string::npos) return split;
+		rx = replystr[p+2];
 // split test
-	split = (tx == '1' ? 2 : 0) + (rx == '1' ? 1 : 0);
-
+		split = (tx == '1' ? 2 : 0) + (rx == '1' ? 1 : 0);
+	}
 	return split;
 }
 
@@ -346,9 +342,8 @@ int RIG_TS870S::get_split()
 long RIG_TS870S::get_vfoA ()
 {
 	cmd = "FA;";
-	int ret = waitN(14, 100, "get vfoA", ASC);
+	if (wait_char(';', 14, 100, "get vfoA", ASC) < 14) return A.freq;
 
-	if (ret < 14) return A.freq;
 	size_t p = replystr.rfind("FA");
 	if (p == string::npos) return A.freq;
 
@@ -371,17 +366,16 @@ void RIG_TS870S::set_vfoA (long freq)
 		cmd[i] += freq % 10;
 		freq /= 10;
 	}
-	sendCommand(cmd, 0);
-	showresp(WARN, ASC, "set vfo A", cmd, replystr);
+	sendCommand(cmd);
+	showresp(WARN, ASC, "set vfo A", cmd, "");
 }
 
 //----------------------------------------------------------------------
 long RIG_TS870S::get_vfoB ()
 {
 	cmd = "FB;";
-	int ret = waitN(14, 100, "get vfoB", ASC);
+	if (wait_char(';', 14, 100, "get vfoB", ASC) < 14) return B.freq;
 
-	if (ret < 14) return B.freq;
 	size_t p = replystr.rfind("FB");
 	if (p == string::npos) return B.freq;
 
@@ -405,34 +399,15 @@ void RIG_TS870S::set_vfoB (long freq)
 		cmd[i] += freq % 10;
 		freq /= 10;
 	}
-	sendCommand(cmd, 0);
-	showresp(WARN, ASC, "set vfo B", cmd, replystr);
+	sendCommand(cmd);
+	showresp(WARN, ASC, "set vfo B", cmd, "");
 }
 
 //----------------------------------------------------------------------
-/* int RIG_TS870S::get_smeter() {
-	int mtr = 0;
+int RIG_TS870S::get_smeter() {
 	cmd = "SM;";
-	int ret = waitN(8, 100, "get smeter", ASC);
+	if (wait_char(';', 7, 100, "get smeter", ASC) < 7) return 0;
 
-	if (ret < 7) return 0;
-	size_t p = replystr.find("SM");
-	if (p == string::npos) return 0;
-
-	replystr[p + 6] = 0;
-	mtr = atoi(&replystr[p + 2]);
-	mtr *= 50;
-	mtr /= 15;
-	if (mtr > 100) mtr = 100;
-	return mtr;
-} */
-
-//----------------------------------------------------------------------
-int RIG_TS870S::get_smeter() {	 // scales correctly now 2012-02-24
-	cmd = "SM;";
-	int ret = sendCommand(cmd);
-	showresp(WARN, ASC, "S meter", cmd, replystr);
-	if (ret < 7) return 0;
 	size_t p = replystr.rfind("SM");
 	if (p == string::npos) return -1;
 
@@ -447,9 +422,8 @@ int RIG_TS870S::get_power_out()
 { // Shares same command as the 'S' meter reading.
 	int mtr = 0;
 	cmd = "SM;";
-	int ret = sendCommand(cmd);
-	showresp(WARN, ASC, "Output Power", cmd, replystr);
-	if (ret < 7) return mtr;
+	if (wait_char(';', 7, 100, "get output power", ASC) < 7) return mtr;
+
 	size_t p = replystr.rfind("SM");
 	if (p == string::npos) return mtr;
 
@@ -461,6 +435,8 @@ int RIG_TS870S::get_power_out()
 
 	// The power meter scale is not the same as Flrig's default.
 	// a change is needed, one day.   wbx2
+	// Note that the power meter scale is an image and would have to be
+	// redrawn and then set specifically for the xcvr in support.cxx
 }
 
 //----------------------------------------------------------------------
@@ -473,23 +449,20 @@ void RIG_TS870S::set_power_control(double val)
 		cmd[i] += ival % 10;
 		ival /= 10;
 	}
-	sendCommand(cmd, 0); // 010 .. 100
+	sendCommand(cmd); // 010 .. 100
 }
 
 //----------------------------------------------------------------------
 int RIG_TS870S::get_power_control()
 {
 	cmd = "PC;";
-	int ret = waitN(6, 100, "get pwr ctrl", ASC);
+	if (wait_char(';', 6, 100, "get pwr ctrl", ASC) < 6) return 0;
 
-	if (ret < 6) return 0;
 	size_t p = replystr.rfind("PC");
 	if (p == string::npos) return 0;
 	int mtr = 0;
-	if (ret >= 6) {
-		replystr[p + 5] = 0;
-		mtr = atoi(&replystr[p + 2]);
-	}
+	replystr[p + 5] = 0;
+	mtr = atoi(&replystr[p + 2]);
 	return mtr;
 }
 
@@ -499,12 +472,8 @@ int RIG_TS870S::get_volume_control()
 {
 	cmd = "AG;";  // reply data is 'AGnnn;' nnn = 000 .. 255  wbx
 
-	int ret = sendCommand(cmd);
-	showresp(WARN, ASC, "get vol ctrl", cmd, replystr);
+	if (wait_char(';', 6, 100, "get vol ctrl", ASC) < 6) return 0;
 
-//	int ret = waitN(7, 100, "get vol ctrl", ASC);
-
-	if (ret < 6) return 0;
 	size_t p = replystr.rfind("AG");
 	if (p == string::npos) return 0;
 
@@ -522,7 +491,7 @@ void RIG_TS870S::set_volume_control(int val) // 0 .. 100
 		cmd[i] += ivol % 10;
 		ivol /= 10;
 	}
-	sendCommand(cmd, 0);
+	sendCommand(cmd);
 }
 
 //----------------------------------------------------------------------
@@ -536,13 +505,15 @@ void RIG_TS870S::set_volume_control(int val) // 0 .. 100
  * there, and blank the mic.
  * To do that, in the Config/Xcvr Select menu, use one of the Hardware PTT options.
  * Just so it has been said...
+ * 
+ * BUMMER - HKJ
  */
 
 void RIG_TS870S::set_PTT_control(int val)
 {
 	if (val) cmd = "TX;";
 	else	 cmd = "RX;";
-	sendCommand(cmd, 0);
+	sendCommand(cmd);
 }
 
 //----------------------------------------------------------------------
@@ -550,7 +521,7 @@ void RIG_TS870S::set_PTT_control(int val)
 void RIG_TS870S::tune_rig()
 {
 //	cmd = "AC111;";
-//	sendCommand(cmd, 0);
+//	sendCommand(cmd);
 
 	// this might take a while!
 }
@@ -582,16 +553,15 @@ void RIG_TS870S::set_attenuator(int val) {
 	}
 
 	sendCommand(cmd);
-	showresp(WARN, ASC, "set Att", cmd, replystr);
+	showresp(WARN, ASC, "set Att", cmd, "");
 }
 
 //----------------------------------------------------------------------
 //	Modified to read and show the actual radio setting, in the button.
 int RIG_TS870S::get_attenuator() {
 	cmd = "RA;";
-	int ret = sendCommand(cmd);
-	showresp(WARN, ASC, "get Att", cmd, replystr);
-	if (ret < 5) return att_on;
+	if (wait_char(';', 5, 100, "get att", ASC) < 5) return att_on;
+
 	size_t p = replystr.rfind("RA");
 	if (p == string::npos) return att_on;
 
@@ -622,9 +592,8 @@ int RIG_TS870S::get_attenuator() {
 //----------------------------------------------------------------------
 bool RIG_TS870S::get_TS870Sid() {
 	cmd = "ID;";
-	int ret = sendCommand(cmd);
-	showresp(WARN, ASC, "Id", cmd, replystr);
-	if (ret < 6) return false;
+	if (wait_char(';', 6, 100, "get ID", ASC) < 6) return false;
+
 	size_t p = replystr.rfind("ID");			// String "ID015;"
 	if (p == string::npos) return false;		// Bytes   012345
 	if 	(replystr[p + 2] == '0' &&				// wbx2
@@ -642,8 +611,8 @@ void RIG_TS870S::set_modeA(int val)
 	cmd = "MD";
 	cmd += TS870S_mode_chr[val];
 	cmd += ';';
-	sendCommand(cmd, 0);
-	showresp(WARN, ASC, "set mode A", cmd, replystr);
+	sendCommand(cmd);
+	showresp(WARN, ASC, "set mode A", cmd, "");
 
 	set_widths(val);
 }
@@ -653,9 +622,8 @@ int RIG_TS870S::get_modeA()
 {
 	int md = A.imode;
 	cmd = "MD;";
-	int ret = waitN(4, 100, "get mode A", ASC);
+	if (wait_char(';', 4, 100, "get mode A", ASC) < 4) return A.imode;
 
-	if (ret < 4) return A.imode;
 	size_t p = replystr.rfind("MD");
 	if (p == string::npos) return A.imode;
 
@@ -685,8 +653,8 @@ void RIG_TS870S::set_modeB(int val)
 	cmd = "MD";
 	cmd += TS870S_mode_chr[val];
 	cmd += ';';
-	sendCommand(cmd, 0);
-	showresp(WARN, ASC, "set mode B", cmd, replystr);
+	sendCommand(cmd);
+	showresp(WARN, ASC, "set mode B", cmd, "");
 
 	set_widths(val);
 }
@@ -696,9 +664,8 @@ int RIG_TS870S::get_modeB()
 {
 	int md = B.imode;
 	cmd = "MD;";
-	int ret = waitN(4, 100, "get mode B", ASC);
+	if (wait_char(';', 4, 100, "get mode B", ASC) < 4) return B.imode;
 
-	if (ret < 4) return B.imode;
 	size_t p = replystr.rfind("MD");
 	if (p == string::npos) return B.imode;
 
@@ -731,14 +698,14 @@ int RIG_TS870S::set_widths(int val) // val is from the mode list index, as selec
 	int bw = 0;
 
 	if (val == tsLSB || val == tsUSB ) {  // SSB modes
-		bandwidths_ = TS870S_empty;
+		bandwidths_ = TS870S_SSB_hi;
 		dsp_lo = TS870S_SSB_lo;
 		dsp_hi = TS870S_SSB_hi;
 		lo_tooltip = TS870S_SSB_lo_tooltip;
 		lo_label   = TS870S_SSB_btn_lo_label;
 		hi_tooltip = TS870S_SSB_hi_tooltip;
 		hi_label   = TS870S_SSB_btn_hi_label;
-		bw = 0x8704; // 300 ... 2800 Hz
+		bw = DEF_lo_hi; // 300 ... 2800 Hz
 	}
 
 	else if (val == tsCW || val == tsCWR) {  // CW modes
@@ -781,7 +748,9 @@ int RIG_TS870S::set_widths(int val) // val is from the mode list index, as selec
 const char **RIG_TS870S::bwtable(int m)
 {
 	if (m == tsLSB || m == tsUSB || m == tsAM)
-		return NULL;  // these modes have lo and hi settings.
+// these modes have lo and hi settings. BUT MUST RETURN A VALID pointer
+// NOT EMPTY!
+		return TS870S_SSB_hi;  
 
 	else if (m == tsCW || m == tsCWR)
 		return TS870S_CWwidths;
@@ -793,7 +762,7 @@ const char **RIG_TS870S::bwtable(int m)
 		return TS870S_FMwidths;
 
 	else
-		return NULL;
+		return TS870S_SSB_hi;
 }
 
 const char **RIG_TS870S::lotable(int m)
@@ -802,13 +771,13 @@ const char **RIG_TS870S::lotable(int m)
 		return TS870S_SSB_lo;  // these modes have lo and hi settings.
 
 	else if (m == tsCW || m == tsCWR)
-		return NULL;
+		return TS870S_empty;
 
 	else if (m == tsFSK || m == tsFSKR)
-		return NULL;
+		return TS870S_empty;
 
 	else if (m == tsFM)
-		return NULL;
+		return TS870S_empty;
 
 	else
 		return TS870S_AM_lo;
@@ -820,13 +789,13 @@ const char **RIG_TS870S::hitable(int m)
 		return TS870S_SSB_hi;  // these modes have lo and hi settings.
 
 	else if (m == tsCW || m == tsCWR)
-		return NULL;
+		return TS870S_empty;
 
 	else if (m == tsFSK || m == tsFSKR)
-		return NULL;
+		return TS870S_empty;
 
 	else if (m == tsFM)
-		return NULL;
+		return TS870S_empty;
 
 	else
 		return TS870S_AM_hi;
@@ -836,7 +805,7 @@ const char **RIG_TS870S::hitable(int m)
 int RIG_TS870S::adjust_bandwidth(int val)
 {
 	if (val == tsLSB || val == tsUSB )
-		return 0x8704; // 2800Hz .. 300Hz
+		return DEF_lo_hi; // 2800Hz .. 300Hz
 
 	else if (val == tsCW || val == tsCWR)
 		return 2; // 200Hz
@@ -867,11 +836,11 @@ void RIG_TS870S::set_bwA(int val)
 
 		cmd = TS870S_CAT_ssb_lo[A.iBW & 0x7F];
 		sendCommand(cmd,0);
-		showresp(WARN, ASC, "set lower", cmd, replystr);
+		showresp(WARN, ASC, "set lower", cmd, "");
 
 		cmd = TS870S_CAT_ssb_hi[(A.iBW >> 8) & 0x7F];
 		sendCommand(cmd,0);
-		showresp(WARN, ASC, "set upper", cmd, replystr);
+		showresp(WARN, ASC, "set upper", cmd, "");
 
 		return;
 	}
@@ -883,11 +852,11 @@ void RIG_TS870S::set_bwA(int val)
 
 		cmd = TS870S_CAT_am_lo[A.iBW & 0x7F];
 		sendCommand(cmd,0);
-		showresp(WARN, ASC, "set lower", cmd, replystr);
+		showresp(WARN, ASC, "set lower", cmd, "");
 
 		cmd = TS870S_CAT_am_hi[(A.iBW >> 8) & 0x7F];
 		sendCommand(cmd,0);
-		showresp(WARN, ASC, "set upper", cmd, replystr);
+		showresp(WARN, ASC, "set upper", cmd, "");
 
 		return;
 	}
@@ -898,7 +867,7 @@ void RIG_TS870S::set_bwA(int val)
 		A.iBW = val;
 		cmd = TS870S_CWbw[A.iBW];
 		sendCommand(cmd,0);
-		showresp(WARN, ASC, "set CW bw", cmd, replystr);
+		showresp(WARN, ASC, "set CW bw", cmd, "");
 		return;
 	}
 
@@ -907,7 +876,7 @@ void RIG_TS870S::set_bwA(int val)
 		A.iBW = val;
 		cmd = TS870S_FSKbw[A.iBW];
 		sendCommand(cmd,0);
-		showresp(WARN, ASC, "set FSK bw", cmd, replystr);
+		showresp(WARN, ASC, "set FSK bw", cmd, "");
 		return;
 	}
 
@@ -916,7 +885,7 @@ void RIG_TS870S::set_bwA(int val)
 		A.iBW = val;
 		cmd = TS870S_FMbw[A.iBW];
 		sendCommand(cmd,0);
-		showresp(WARN, ASC, "set FM bw", cmd, replystr);
+		showresp(WARN, ASC, "set FM bw", cmd, "");
 		return;
 	}
 }
@@ -930,11 +899,11 @@ void RIG_TS870S::set_bwB(int val)
 
 		cmd = TS870S_CAT_ssb_lo[B.iBW & 0x7F];
 		sendCommand(cmd,0);
-		showresp(WARN, ASC, "set lower", cmd, replystr);
+		showresp(WARN, ASC, "set lower", cmd, "");
 
 		cmd = TS870S_CAT_ssb_hi[(B.iBW >> 8) & 0x7F];
 		sendCommand(cmd,0);
-		showresp(WARN, ASC, "set upper", cmd, replystr);
+		showresp(WARN, ASC, "set upper", cmd, "");
 
 		return;
 	}
@@ -945,11 +914,11 @@ void RIG_TS870S::set_bwB(int val)
 
 		cmd = TS870S_CAT_am_lo[B.iBW & 0x7F];  			// corrected wbx2
 		sendCommand(cmd,0);
-		showresp(WARN, ASC, "set lower", cmd, replystr);
+		showresp(WARN, ASC, "set lower", cmd, "");
 
 		cmd = TS870S_CAT_am_hi[(B.iBW >> 8) & 0x7F];	// corrected wbx2
 		sendCommand(cmd,0);
-		showresp(WARN, ASC, "set upper", cmd, replystr);
+		showresp(WARN, ASC, "set upper", cmd, "");
 
 		return;
 	}
@@ -960,7 +929,7 @@ void RIG_TS870S::set_bwB(int val)
 		B.iBW = val;
 		cmd = TS870S_CWbw[B.iBW];
 		sendCommand(cmd,0);
-		showresp(WARN, ASC, "set CW bw", cmd, replystr);
+		showresp(WARN, ASC, "set CW bw", cmd, "");
 		return;
 	}
 
@@ -968,7 +937,7 @@ void RIG_TS870S::set_bwB(int val)
 		B.iBW = val;
 		cmd = TS870S_FSKbw[B.iBW];
 		sendCommand(cmd,0);
-		showresp(WARN, ASC, "set FSK bw", cmd, replystr);
+		showresp(WARN, ASC, "set FSK bw", cmd, "");
 		return;
 	}
 
@@ -976,7 +945,7 @@ void RIG_TS870S::set_bwB(int val)
 		A.iBW = val;
 		cmd = TS870S_FMbw[A.iBW];
 		sendCommand(cmd,0);
-		showresp(WARN, ASC, "set FM bw", cmd, replystr);
+		showresp(WARN, ASC, "set FM bw", cmd, "");
 		return;
 	}
 
@@ -989,10 +958,10 @@ int RIG_TS870S::get_bwA() {
 	size_t p;
 
 	if (A.imode == tsFM) { // FM mode.
-		cmd = "FW;"; // 'Filter Width' query
-		waitN(7, 100, "get CW width", ASC);
-		p = replystr.rfind("FW");
+		cmd = "FW;"; // 'width' query
+		if (wait_char(';', 7, 100, "get CW width", ASC) < 7) return A.iBW;
 
+		p = replystr.rfind("FW");
 		if (p != string::npos) { // If 'FW' found then scan the known responces to find out what we got.
 			for (i = 0; TS870S_FMbw[i] != NULL; i++) // bump array index counter, till string match or end.
 				if (replystr.find(TS870S_FMbw[i]) == p) break; 	// Found returned data, in string array.
@@ -1003,10 +972,10 @@ int RIG_TS870S::get_bwA() {
 	}
 
 	else if (A.imode == tsCW || A.imode == tsCWR) { // CW modes.
-		cmd = "FW;"; // 'Filter Width' query
-		waitN(7, 100, "get CW width", ASC);
-		p = replystr.rfind("FW");
+		cmd = "FW;"; // 'width' query
+		if (wait_char(';', 7, 100, "get CW width", ASC) < 7) return A.iBW;
 
+		p = replystr.rfind("FW");
 		if (p != string::npos) { // If 'FW' found then scan the known responces to find out what we got.
 			for (i = 0; TS870S_CWbw[i] != NULL; i++) // bump array index counter, till string match or end.
 				if (replystr.find(TS870S_CWbw[i]) == p) break; 	// Found returned data, in string array.
@@ -1018,9 +987,9 @@ int RIG_TS870S::get_bwA() {
 
 	else if (A.imode == tsFSK || A.imode == tsFSKR ) { // FSK modes.
 		cmd = "FW;";
-		waitN(7, 100, "get FSK width", ASC);
-		p = replystr.rfind("FW");
+		if (wait_char(';', 7, 100, "get FSK width", ASC) < 7) return A.iBW;
 
+		p = replystr.rfind("FW");
 		if (p != string::npos) { // If 'FW' found then scan the known responces to find out what we got.
 			for (i = 0; TS870S_FSKbw[i] != NULL; i++) // bump array index counter, till string match or end.
 				if (replystr.find(TS870S_FSKbw[i]) == p) break; 	// Found returned data, in string array.
@@ -1034,12 +1003,12 @@ int RIG_TS870S::get_bwA() {
 	else if (A.imode == tsAM) { // AM mode only
 
 		int lo = A.iBW & 0x7F, hi = (A.iBW >> 8) & 0x7F;
-		// High byte is hi cutoff index (not MSB though.) Low byte is lo cuttoff index.
+		// High byte is hi cut index (not MSB though.) Low byte is lo cuttoff index.
 
 		cmd = "FW;"; // Read Low cuttoff. Returns a two digit code as 'FLxxxx;' in 10Hz increments.
-		waitN(5, 100, "get lower", ASC);
-		p = replystr.rfind("FW");
+		if (wait_char(';', 5, 100, "get lower", ASC) < 5) return A.iBW;
 
+		p = replystr.rfind("FW");
 		if (p != string::npos) { // If 'FW' found then scan the known responces to find out what we got.
 			for (i = 0; TS870S_CAT_am_lo[i] != NULL; i++) // bump array index counter, till string match or end.
 				if (replystr.find(TS870S_CAT_am_lo[i]) == p) break; 	// Found returned data, in string array.
@@ -1049,18 +1018,18 @@ int RIG_TS870S::get_bwA() {
 		}
 
 		cmd = "IS;";
-		waitN(5, 100, "get upper", ASC);
-		p = replystr.rfind("IS ");
+		if (wait_char(';', 5, 100, "get upper", ASC) == 5) {
+			p = replystr.rfind("IS ");
+			if (p != string::npos) {
+				for (i = 0; TS870S_CAT_am_hi[i] != NULL; i++) // bump array index counter, till string match or end.
+					if (replystr.find(TS870S_CAT_am_hi[i]) == p) break; 	// Found returned data, in string array.
 
-		if (p != string::npos) {
-			for (i = 0; TS870S_CAT_am_hi[i] != NULL; i++) // bump array index counter, till string match or end.
-				if (replystr.find(TS870S_CAT_am_hi[i]) == p) break; 	// Found returned data, in string array.
-
-			if (TS870S_CAT_am_hi[i] != NULL) hi = i; // if we didn't hit the end, return the array index value.
-			else hi = 1; // Default.
-		}
-		A.iBW = ((hi << 8) | (lo & 0x7F)) | 0x8000;
+				if (TS870S_CAT_am_hi[i] != NULL) hi = i; // if we didn't hit the end, return the array index value.
+				else hi = 1; // Default.
+			}
+			A.iBW = ((hi << 8) | (lo & 0x7F)) | 0x8000;
 		// Shift hi index up 8 bits into High Byte, then concatntat it with the Low byte, into one 16 bit value.
+		}
 	}
 
 
@@ -1069,9 +1038,9 @@ int RIG_TS870S::get_bwA() {
 		int lo = A.iBW & 0x7F, hi = (A.iBW >> 8) & 0x7F; // Same trick as above...
 
 		cmd = "FW;"; // Read Low cuttoff. Returns a two digit code as 'FLxxxx;' in 10Hz increments.
-		waitN(5, 100, "get lower", ASC);
-		p = replystr.rfind("FW");
+		if (wait_char(';', 5, 100, "get lower", ASC) < 5) return A.iBW;
 
+		p = replystr.rfind("FW");
 		if (p != string::npos) { // If 'FW' found then scan the known responces to find out what we got.
 			for (i = 0; TS870S_CAT_ssb_lo[i] != NULL; i++) // bump array index counter, till string match or end.
 				if (replystr.find(TS870S_CAT_ssb_lo[i]) == p) break; 	// Found returned data, in string array.
@@ -1081,7 +1050,8 @@ int RIG_TS870S::get_bwA() {
 		}
 
 		cmd = "IS;";
-		waitN(5, 100, "get upper", ASC);
+		if (wait_char(';', 5, 100, "get upper", ASC) < 5) return A.iBW;
+
 		p = replystr.rfind("IS ");
 
 		if (p != string::npos) {
@@ -1103,10 +1073,10 @@ int RIG_TS870S::get_bwB()
 	size_t p;
 
 	if (B.imode == tsFM) {
-		cmd = "FW;"; // 'Filter Width' query
-		waitN(7, 100, "get CW width", ASC);
-		p = replystr.rfind("FW");
+		cmd = "FW;"; // 'width' query
+		if (wait_char(';', 7, 100, "get CW width", ASC) < 7) return B.iBW;
 
+		p = replystr.rfind("FW");
 		if (p != string::npos) { // If 'FW' found then scan the known responces to find out what we got.
 			for (i = 0; TS870S_FMbw[i] != NULL; i++) // bump array index counter, till string match or end.
 				if (replystr.find(TS870S_FMbw[i]) == p) break; 	// Found returned data, in string array.
@@ -1117,10 +1087,10 @@ int RIG_TS870S::get_bwB()
 	}
 
 	else if (B.imode == tsCW || B.imode == tsCWR) { // CW modes.
-		cmd = "FW;"; // 'Filter Width' query
-		waitN(7, 100, "get CW width", ASC);
-		p = replystr.rfind("FW");
+		cmd = "FW;"; // 'width' query
+		if (wait_char(';', 7, 100, "get CW width", ASC) < 7) return B.iBW;
 
+		p = replystr.rfind("FW");
 		if (p != string::npos) { // If 'FW' found then scan the known responces to find out what we got.
 			for (i = 0; TS870S_CWbw[i] != NULL; i++) // bump array index counter, till string match or end.
 				if (replystr.find(TS870S_CWbw[i]) == p) break; 	// Found returned data, in string array.
@@ -1132,9 +1102,9 @@ int RIG_TS870S::get_bwB()
 
 	else if (B.imode == tsFSK || B.imode == tsFSKR) { // FSK modes.
 		cmd = "FW;";
-		waitN(7, 100, "get FSK width", ASC);
-		p = replystr.rfind("FW");
+		if (wait_char(';', 7, 100, "get FSK width", ASC) < 7) return B.iBW;
 
+		p = replystr.rfind("FW");
 		if (p != string::npos) { // If 'FW' found then scan the known responces to find out what we got.
 			for (i = 0; TS870S_FSKbw[i] != NULL; i++) // bumb array index counter, till string match or end.
 				if (replystr.find(TS870S_FSKbw[i]) == p) break; 	// Found returned data, in string array.
@@ -1149,9 +1119,9 @@ int RIG_TS870S::get_bwB()
 		int lo = B.iBW & 0x7F, hi = (B.iBW >> 8) & 0x7F;
 
 		cmd = "FW;"; // Read Low cuttoff. Returns a two digit code as 'FLxxxx;' in 10Hz increments.
-		waitN(5, 100, "get lower", ASC);
-		p = replystr.rfind("FW");
+		if (wait_char(';', 5, 100, "get lower", ASC) < 5) return B.iBW;
 
+		p = replystr.rfind("FW");
 		if (p != string::npos) { // If 'FW' found then scan the known responces to find out what we got.
 			for (i = 0; TS870S_CAT_am_lo[i] != NULL; i++) // bump array index counter, till string match or end.
 				if (replystr.find(TS870S_CAT_am_lo[i]) == p) break; 	// Found returned data, in string array.
@@ -1161,9 +1131,9 @@ int RIG_TS870S::get_bwB()
 		}
 
 		cmd = "IS;";
-		waitN(5, 100, "get upper", ASC);
-		p = replystr.rfind("IS ");
+		if (wait_char(';', 5, 100, "get upper", ASC) < 5) return B.iBW;
 
+		p = replystr.rfind("IS ");
 		if (p != string::npos) {
 			for (i = 0; TS870S_CAT_am_hi[i] != NULL; i++) // bump array index counter, till string match or end.
 				if (replystr.find(TS870S_CAT_am_hi[i]) == p) break; 	// Found returned data, in string array.
@@ -1180,9 +1150,9 @@ int RIG_TS870S::get_bwB()
 		int lo = B.iBW & 0x7F, hi = (B.iBW >> 8) & 0x7F;
 
 		cmd = "FW;"; // Read Low cuttoff. Returns a two digit code as 'FLxxxx;' in 10Hz increments.
-		waitN(5, 100, "get lower", ASC);
-		p = replystr.rfind("FW");
+		if (wait_char(';', 5, 100, "get lower", ASC) < 5) return  B.iBW;
 
+		p = replystr.rfind("FW");
 		if (p != string::npos) { // If 'FW' found then scan the known responces to find out what we got.
 			for (i = 0; TS870S_CAT_ssb_lo[i] != NULL; i++) // bump array index counter, till string match or end.
 				if (replystr.find(TS870S_CAT_ssb_lo[i]) == p) break; 	// Found returned data, in string array.
@@ -1192,9 +1162,9 @@ int RIG_TS870S::get_bwB()
 		}
 
 		cmd = "IS;";
-		waitN(5, 100, "get upper", ASC);
-		p = replystr.rfind("IS ");
+		if (wait_char(';', 5, 100, "get upper", ASC)  < 5) return B.iBW;
 
+		p = replystr.rfind("IS ");
 		if (p != string::npos) {
 			for (i = 0; TS870S_CAT_ssb_hi[i] != NULL; i++) // bump array index counter, till string match or end.
 				if (replystr.find(TS870S_CAT_ssb_hi[i]) == p) break; 	// Found returned data, in string array.
@@ -1223,7 +1193,7 @@ void RIG_TS870S::set_mic_gain(int val)
 		cmd[1+i] += imic % 10;
 		imic /= 10;
 	}
- 	sendCommand(cmd, 0);
+ 	sendCommand(cmd);
 }
 
 //----------------------------------------------------------------------
@@ -1231,9 +1201,7 @@ int RIG_TS870S::get_mic_gain()
 {
 	int val = 0;
 	cmd = "MG;";
-	int ret = waitN(6, 100, "get mic ctrl", ASC);
-
-	if (ret >= 6) {
+	if (wait_char(';', 6, 100, "get mic ctrl", ASC) >= 6) {
 		size_t p = replystr.rfind("MG");
 		if (p == string::npos) return val;
 		replystr[p + 5] = 0;
@@ -1258,15 +1226,14 @@ void RIG_TS870S::set_noise(bool val)
 	else
 		cmd = "NB0;";
 	sendCommand(cmd);
-	showresp(WARN, ASC, "set NB", cmd, replystr);
+	showresp(WARN, ASC, "set NB", cmd, "");
 }
 
 int  RIG_TS870S::get_noise()
 {
 	cmd = "NB;";
-	int ret = sendCommand(cmd);
-	showresp(WARN, ASC, "get NB", cmd, replystr);
-	if (ret < 4) return 0;
+	if (wait_char(';', 4, 100, "get NB", ASC) < 4) return 0;
+
 	size_t p = replystr.rfind("NB");
 	if (p == string::npos) return 0;
 
@@ -1287,7 +1254,7 @@ void RIG_TS870S::set_if_shift(int val)
 		cmd = "IS ";
 		cmd.append(to_decimal(abs(val),4)).append(";");
 		sendCommand(cmd,0);
-		showresp(WARN, ASC, "set IF shift", cmd, replystr);
+		showresp(WARN, ASC, "set IF shift", cmd, "");
 	}
 }
 
@@ -1296,7 +1263,10 @@ bool RIG_TS870S::get_if_shift(int &val)
 {
 	if (active_mode == tsCW || active_mode == tsCWR) { // cw modes
 		cmd = "IS;";
-		waitN(8, 100, "get IF shift", ASC);
+		if (wait_char(';', 8, 100, "get IF shift", ASC) < 8) {
+			val = progStatus.shift_val;
+			return false;
+		}
 		size_t p = replystr.rfind("IS");
 		if (p != string::npos) {
 			val = fm_decimal(&replystr[p+3], 4);
@@ -1318,17 +1288,20 @@ void RIG_TS870S::get_if_min_max_step(int &min, int &max, int &step)
 }
 
 //----------------------------------------------------------------------
+// Dave, G0WBX, does this work?
+// I do not see a BP in the 870 command table
+//
 void RIG_TS870S::set_notch(bool on, int val)
 {
 	cmd = "BP00000;";
 	if (on == false) {
-		sendCommand(cmd, 0);
+		sendCommand(cmd);
 		notch_on = false;
 		return;
 	}
 	if (!notch_on) {
 		cmd[6] = '1'; // notch ON
-		sendCommand(cmd, 0);
+		sendCommand(cmd);
 		cmd[6] = '0';
 		notch_on = true;
 	}
@@ -1341,7 +1314,7 @@ void RIG_TS870S::set_notch(bool on, int val)
 		cmd[3 + i] += val % 10;
 		val /=10;
 	}
-	sendCommand(cmd, 0);
+	sendCommand(cmd);
 }
 
 //----------------------------------------------------------------------
